==> lintian_2.106.0.tar.xz: lintian-2.106.0/lib/Lintian/Check/Libraries/Shared/Obsolete.pm <==
# libraries/shared/obsolete -- lintian check script -*- perl -*-

# Copyright © 2020 Mo Zhou
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::Check::Libraries::Shared::Obsolete;

use v5.20;
use warnings;
use utf8;

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub visit_installed_files {
    my ($self, $file) = @_;

    return
      unless $file->is_file;

    return
      unless $file->file_info =~ /^[^,]*\bELF\b/;

    my $objdump = $self->processable->objdump_info->{$file->name};

    my @needed = @{$objdump->{NEEDED} // []};
    my @obsolete = grep { /^libcblas\.so\.\d/ } @needed;

    $self->hint('linked-with-obsolete-library', $_, $file->name) for @obsolete;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et

==> lintian_2.126.0.tar.xz: lintian-2.126.0/lib/Lintian/Check/Libraries/Shared/Obsolete.pm <==
# libraries/shared/obsolete -- lintian check script -*- perl -*-

# Copyright (C) 2020 Mo Zhou
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at https://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::Check::Libraries::Shared::Obsolete;

use v5.20;
use warnings;
use utf8;

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub visit_installed_files {
    my ($self, $item) = @_;

    return
      unless $item->is_file;

    return
      unless $item->file_type =~ /^[^,]*\bELF\b/;

    my @needed = @{$item->elf->{NEEDED} // []};
    my @obsolete = grep { /^libcblas\.so\.\d/ } @needed;

    $self->pointed_hint('linked-with-obsolete-library', $item->pointer, $_)
      for @obsolete;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
